TELEWORK TELEWORK TELEWORK

特集

テレワークのさらなる普及·定着に向け「テレワーク月間」を実施します\! TELEWORK

ORK TELEWORK TELEWORK TELEWORK TELEWORK TELEWORK

# テレワークのさらなる普及·定着に向け<br>「テレワーク月間」<br>を実施します\!

<img src="figures/in_gallery1_p1_figure_0.png" width="200px"><br>
今年度は育児·介護休業法の改正法が成立し、<br>来年度以降は3歳未満の子を育てる社員がテレ<br>ワークを選択できるように措置を講ずることが、<br>事業主の努力義務になります。

総務省では、地方や中小企業等を含め、テレ<br>ワークの活用により、多様な働き手が活躍の機<br>会を持てるよう、テレビ番組とのタイアップを<br>通じて、テレワークの必要性を改めて実感でき<br>るような情報発信を行います。また、全国の総<br>合通信局等では、それぞれの地域における取組<br>やテレワーク活用を進める先進企業を紹介する<br>催しを実施します。

総務省は、内閣官房、内閣府、デジタル庁、<br>厚生労働省、経済産業省、国土交通省、観光庁、<br>環境省、日本テレワーク協会、日本テレワーク<br>学会と連携して、11月をテレワーク月間とし、<br>テレワークのさらなる普及·定着に向けた各種<br>イベント等を集中的に開催します。テレワーク<br>月間期間中は駅構内やイベント会場等にポス<br>ターを掲出するほか、ホームページ\(※\)にて、テ<br>レワーク実施団体·実施者の登録受付や、テレ<br>ワーク活用に関するトピック·コンテンツの掲<br>載、各種イベントに係る情報発信等を行います。

<img src="figures/in_gallery1_p1_figure_1.png" width="200px"><br>
令和6年度テレワーク月間ポスター

<img src="figures/in_gallery1_p1_figure_2.png" width="200px"><br>
<img src="figures/in_gallery1_p1_figure_3.png" width="200px"><br>
※テレワーク月間ホームページ

https://teleworkgekkan\.go\.jp/

特集

テレワーク月間最終週の11月25日\(月\)には、内閣府、総務省、厚生労働省、<br>経済産業省、国土交通省主催で「働く、を変える」テレワークイベントを開催し、<br>テレワークトップランナー 2024\(総務大臣賞\)、輝くテレワーク大賞\(厚生労<br>働大臣\)および地方創生テレワークアワード\(地方創生担当大臣賞\)の合同表彰<br>式を実施予定です。

総務省では、平成27年度から、テレワークの導入·活用を進めている企業·<br>団体を「テレワーク先駆者」とし、その中から十分な実績を持つ企業·団体等を<br>「テレワーク先駆者百選」として公表するとともに、平成28年度には「テレワー<br>ク先駆者百選 総務大臣賞」を創設し、「テレワーク先駆者百選」の中から特に優<br>れた取組を表彰してきました。

新型コロナウイルス感染症の拡大に際して、企業·団体等においてテレワー<br>クの導入が進んだ経緯を踏まえ、令和5年度からは、名称や一部の審査基準を<br>見直したうえで、新たに「テレワークトップランナー」として先進企業の公表、<br>表彰を開始しました。本年は、テレワークの活用による経営効果の発揮やテレ<br>ワーク導入が馴染まないと思われている業態の企業におけるテレワーク活用·<br>業務改革等について、特色ある優れた取組等を実施している企業·団体を「テ<br>レワークトップランナー 2024」として選定·公表し、その中から特に優れた取<br>組を「テレワークトップランナー 2024総務大臣賞」として表彰します。※今年度の<br>表彰団体の募集は、すでに終了しています。

表彰式は、会場\(御茶ノ水ソラシティ、東京都\)での観覧の他、オンライン配<br>信も実施予定です。

テレワークの必要性について考え直すきっかけとなるよう、各種イベントに<br>ご参加いただくとともに、テレワーク月間実施団体·実施者としての登録の呼<br>びかけについても、是非、ご協力をお願いします。

テレワークトップランナー 2023 総務大臣賞受賞企業

|企業名<br>\(五十音順\)|業種、所在地、<br>従業員数|取組の特徴|
|-|-|-|
|\|アフラック生命<br>保険株式会社|金融 ·保険業<br>東京都、4910人|·20\-30 代の女性の離職率が半減、育児に関わる短時間勤務制度を利用<br>する社員の人数が 27\.9%減少\(フルタイムの増加\)など、女性の仕事<br>と家庭の両立、キャリア形成に寄与<br>·通勤手当 39\.3%削減、紙帳票のペーパレス化等により、コストダウンの<br>効果も顕在化|
|株式会社<br>キャリア・マム|サービス業<br>東京都、38人|·11万人の主婦会員のうち、年間約3,000 人の地方在住テレワーカーに<br>業務発注を行い、就労支援を実施するとともに、在宅ワーカーとしての<br>人材育成を実施、<br>·地方自治体と連携し、地域でのテレワーカーの創出、テレワーク活用の<br>裾野拡大に貢献|
|シェイプウィン<br>株式会社|専門 ·<br>技術サービス業<br>東京都、17人|·フルリモートでの勤務も可能とし、求人応募数が約7倍に増加。東京<br>では人材獲得の競争が激しい PR·マーケティング系の専門人材を地方<br>や海外から採用<br>·離職率は約 80%から約 14%まで低下|
|株式会社<br>スタッフサービス·<br>クラウドワーク|サービス業<br>神奈川県、454人|·通勤が困難な 454 名の重度身体障がい者の雇用を創出。入社1年後の<br>定着率は97\.3%。<br>·入社後、配属前2ヶ月間のコミュニケーション研修を実施する他、自<br>主性を重んじた1日3回の定時ミーティングにより、社員による主体的<br>なチーム運営を実現\!|
|株式会社<br>テレワーク<br>マネジメント|専門 ·<br>技術サービス業<br>北海道、11人|・社内SNS及びバーチャルオフィスにて社内コミュニケーションを統一し、<br>全員が同じルールの下で活用することを徹底することで、効率の良い意<br>思疎通、社員の一体感の醸成を図っている<br>·簡単な操作で細かく労働時間を記録できるシステムの運用により、フェ<br>アに働ける環境を実現|
|株式会社<br>プログレス|情報通信業<br>東京都、86人|·コミュニケーションの促進に向け、対面でのチームビルディング、バーチャ<br>ルオフィスの活用等、多数の取り組みを進める他、コミュニケーション<br>時の留意点等を示したガイドを全社員に向けて公開<br>·リーダー間でのメンバー状態の共有、社員への毎月サーベイを実施し、<br>社員の変化に対し、きめ細やか且つ早期にフォローできる仕組みを構築|

<img src="figures/in_gallery1_p1_figure_4.png" width="200px"><br>
<img src="figures/in_gallery1_p1_figure_5.png" width="200px"><br>
主催者代表挨拶<br>\(小森総務大臣政務官\)

<img src="figures/in_gallery1_p1_figure_6.png" width="200px"><br>
表彰状授与

<img src="figures/in_gallery1_p1_figure_7.png" width="200px"><br>
受賞企業集合写真\(3府省合同\)

<img src="figures/in_gallery1_p1_figure_8.png" width="200px"><br>
テレワークトップランナー 2023<br>ロゴマーク

<img src="figures/in_gallery1_p1_figure_9.png" width="200px"><br>
テレワーク月間関連イベントの様子

※総務省主催セミナー「ニューノー<br>マル時代に求められる働き方·<br>環境整備の実態」

セミナーのアーカイブ動画を、<br>テレワーク月間ホームページに<br>て公開しております。

https://teleworkgekkan\.go\.jp/events/<br>telework\-seminar\-202403\.html

3

2

MIC 2024 November Vol\.287

2024 November Vol\.287 MIC \.
